# Text Converter

A Python library to convert text into different formats.

## Installation

```bash
pip install textconverterim

```

## Usage
```bash
from textconverterim.converter import to_sentence_case, to_title_case, to_kebab_case
```